module.exports = defineTest({
	description: 'Associates non-string keys with string keys'
});
